--- /dev/null	Sat May 10 12:10:17 2014
+++ new/usr/src/man/man3m/logb.3m	Sat May 10 12:10:17 2014
@@ -0,0 +1,152 @@
+'\" te
+.\" Copyright (c) 2001, the Institute of Electrical and Electronics Engineers, Inc. and The Open Group. All Rights Reserved.
+.\" Copyright (c) 1992, X/Open Company Limited. All Rights Reserved.
+.\" Portions Copyright (c) 2006, Sun Microsystems, Inc.  All Rights Reserved.
+.\" Sun Microsystems, Inc. gratefully acknowledges The Open Group for permission to reproduce portions of its copyrighted documentation. Original documentation from The Open Group can be obtained online at 
+.\" http://www.opengroup.org/bookstore/.
+.\" The Institute of Electrical and Electronics Engineers and The Open Group, have given us permission to reprint portions of their documentation. In the following statement, the phrase "this text" refers to portions of the system documentation. Portions of this text are reprinted and reproduced in electronic form in the Sun OS Reference Manual, from IEEE Std 1003.1, 2004 Edition, Standard for Information Technology -- Portable Operating System Interface (POSIX), The Open Group Base Specifications Issue 6, Copyright (C) 2001-2004 by the Institute of Electrical and Electronics Engineers, Inc and The Open Group. In the event of any discrepancy between these versions and the original IEEE and The Open Group Standard, the original IEEE and The Open Group Standard is the referee document. The original Standard can be obtained online at http://www.opengroup.org/unix/online.html.
+.\"  This notice shall appear on any product containing this material.
+.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
+.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
+.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
+.TH logb 3M "12 Jul 2006" "SunOS 5.11" "Mathematical Library Functions"
+.SH NAME
+logb, logbf, logbl \- radix-independent exponent
+.SH SYNOPSIS
+.LP
+.nf
+c99 [ \fIflag\fR... ] \fIfile\fR... \fB-lm\fR [ \fIlibrary\fR... ]
+#include <math.h>
+
+\fBdouble\fR \fBlogb\fR(\fBdouble\fR \fIx\fR);
+.fi
+
+.LP
+.nf
+\fBfloat\fR \fBlogbf\fR(\fBfloat\fR \fIx\fR);
+.fi
+
+.LP
+.nf
+\fBlong double\fR \fBlogbl\fR(\fBlong double\fR \fIx\fR);
+.fi
+
+.LP
+.nf
+cc [ \fIflag\fR... ] \fIfile\fR... \fB-lm\fR [ \fIlibrary\fR... ]
+#include <math.h>
+
+\fBdouble\fR \fBlogb\fR(\fBdouble\fR \fIx\fR);
+.fi
+
+.LP
+.nf
+\fBfloat\fR \fBlogbf\fR(\fBfloat\fR \fIx\fR);
+.fi
+
+.LP
+.nf
+\fBlong double\fR \fBlogbl\fR(\fBlong double\fR \fIx\fR);
+.fi
+
+.SH DESCRIPTION
+.sp
+.LP
+These functions compute the exponent of \fIx\fR, which is the integral part of
+log(\fIr\fR) |\fIx\fR|, as a signed floating point value, for non-zero \fIx\fR,
+where \fIr\fR is the radix of the machine's floating-point arithmetic, which is
+the value of \fBFLT_RADIX\fR defined in the <\fBfloat.h\fR> header.
+.SH RETURN VALUES
+.sp
+.LP
+Upon successful completion, these functions return the exponent of \fIx\fR.
+.sp
+.LP
+If \fIx\fR is subnormal:
+.RS +4
+.TP
+.ie t \(bu
+.el o
+For SUSv3-conforming applications compiled with the \fBc99\fR compiler driver
+(see \fBstandards\fR(5)), the exponent of \fIx\fR as if \fIx\fR were normalized
+is returned.
+.RE
+.RS +4
+.TP
+.ie t \(bu
+.el o
+Otherwise, if compiled with the \fBcc\fR compiler driver, \(mi1022, \(mi126,
+and \(mi16382 are returned for \fBlogb()\fR, \fBlogbf()\fR, and \fBlogbl()\fR,
+respectively.
+.RE
+.sp
+.LP
+If \fIx\fR is \(+-0, a pole error occurs and \fBlogb()\fR, \fBlogbf()\fR, and
+\fBlogbl()\fR return \(mi\fBHUGE_VAL\fR, \(mi\fBHUGE_VALF\fR, and
+\(mi\fBHUGE_VALL\fR, respectively.
+.sp
+.LP
+If \fIx\fR is NaN, a NaN is returned.
+.sp
+.LP
+If \fIx\fR is \(+-Inf, +Inf is returned.
+.SH ERRORS
+.sp
+.LP
+These functions will fail if:
+.sp
+.ne 2
+.mk
+.na
+\fBPole Error\fR
+.ad
+.RS 14n
+.rt  
+The value of \fIx\fR is \(+-0.
+.sp
+If the integer expression (\fBmath_errhandling\fR & \fBMATH_ERREXCEPT\fR) is
+non-zero, the divide-by-zero floating-point exception is raised.
+.sp
+The \fBlogb()\fR function sets \fBerrno\fR to \fBEDOM\fR if the value of
+\fIx\fR is 0.
+.RE
+
+.SH USAGE
+.sp
+.LP
+An application wanting to check for exceptions should call
+\fBfeclearexcept\fR(\fBFE_ALL_EXCEPT\fR) before calling these functions. On
+return, if \fBfetestexcept\fR(\fBFE_INVALID\fR | \fBFE_DIVBYZERO\fR |
+\fBFE_OVERFLOW\fR | \fBFE_UNDERFLOW\fR) is non-zero, an exception has been
+raised. An application should either examine the return value or check the
+floating point exception flags to detect exceptions.
+.sp
+.LP
+An application can also set \fBerrno\fR to 0 before calling \fBlogb()\fR. On
+return, if \fBerrno\fR is non-zero, an error has occurred. The \fBlogbf()\fR
+and \fBlogbl()\fR functions do not set \fBerrno\fR.
+.SH ATTRIBUTES
+.sp
+.LP
+See \fBattributes\fR(5) for descriptions of the following attributes:
+.sp
+
+.sp
+.TS
+tab() box;
+cw(2.75i) |cw(2.75i) 
+lw(2.75i) |lw(2.75i) 
+.
+ATTRIBUTE TYPEATTRIBUTE VALUE
+_
+Interface StabilityStandard
+_
+MT-LevelMT-Safe
+.TE
+
+.SH SEE ALSO
+.sp
+.LP
+\fBfeclearexcept\fR(3M), \fBfetestexcept\fR(3M), \fBilogb\fR(3M),
+\fBmath.h\fR(3HEAD), \fBmatherr\fR(3M), \fBscalb\fR(3M), \fBattributes\fR(5),
+\fBstandards\fR(5)
